pub enum ExecutionStep {
Sequential {
command: String,
},
ErrorRecovery {
command: String,
},
Pipe {
command: String,
},
PipeErr {
command: String,
},
ContextAccumulation {
commands: Vec<String>,
},
}Expand description
A step in an execution plan describing how a command should be executed.
Variants
Sequential
Execute a command sequentially (normal execution, or first in a chain).
ErrorRecovery
Execute a command and on error, skip to the next ErrorRecovery marker.
Pipe
Execute a command with piped input from the previous command.
PipeErr
Execute a command with piped input including stderr from the previous.
ContextAccumulation
Marker to accumulate optional command outputs into a context object.